'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _listeners = require('./listeners');

var _listeners2 = _interopRequireDefault(_listeners);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Enhances the default addEventListener/removeEventListener
 * Element prototype to listen for our custom "resize" event.
 */
function createEventListeners() {
  var addEventListenerRef = Element.prototype.addEventListener;
  var removeEventListenerRef = Element.prototype.removeEventListener;

  Element.prototype.addEventListener = function (event, handler) {
    var addEvent = addEventListenerRef.bind(this);
    // Adding the custom scroll event
    if (_utils.SUPPORTED_EVENTS.includes(event)) {
      _listeners2.default.addEventListener(this, handler);
    }
    // Execute the default addEventHandler function

    for (var _len = arguments.length, args = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
      args[_key - 2] = arguments[_key];
    }

    return addEvent.apply(undefined, [event, handler].concat(args));
  };

  Element.prototype.removeEventListener = function (event, handler) {
    var removeEvent = removeEventListenerRef.bind(this);
    // Removing the custom scroll event
    if (_utils.SUPPORTED_EVENTS.includes(event)) {
      _listeners2.default.removeEventListener(this, handler);
    }
    // Execute the default removeEventHandler function

    for (var _len2 = arguments.length, args = Array(_len2 > 2 ? _len2 - 2 : 0), _key2 = 2; _key2 < _len2; _key2++) {
      args[_key2 - 2] = arguments[_key2];
    }

    return removeEvent.apply(undefined, [event, handler].concat(args));
  };
}

exports.default = createEventListeners;