'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ScrollListener = require('./ScrollListener');

var _ScrollListener2 = _interopRequireDefault(_ScrollListener);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Stores the collection of listeners for the resize events.
 * @returns { Object } Methods for Listeners
 */
function Listeners() {
  var state = [];

  function add(listener) {
    state.push(listener);
  }

  function find(element) {
    return state.find(function (i) {
      return i.element === element;
    });
  }

  function dispatch() {
    for (var i = 0, len = state.length; i < len; i++) {
      state[i].dispatch();
    }
  }

  function getState() {
    return state;
  }

  function remove(listener) {
    state.splice(state.indexOf(listener), 1);
  }

  return {
    add: add,
    addEventListener: function (element, handler) {
      if (!find(element)) {
        var listener = new _ScrollListener2.default(element, handler);
        element.addEventListener('scroll', listener.dispatch.bind(listener));
        add(listener);
      }
    },
    clear: function () {
      state = [];
    },
    dispatch: dispatch,
    find: find,
    getState: getState,
    remove: remove,
    removeEventListener: function (element) {
      var listener = find(element);
      var el = listener.element;
      element.removeEventListener('scroll', listener.dispatch.bind(listener));
      // Remove reference to DOM node, if it no longer exists
      if (!el || !el.ownerDocument.contains(el)) {
        remove(listener);
      }
    }
  };
}

var createListeners = function () {
  return new Listeners();
};

exports.default = createListeners;